@@ -391,6 +391,74 @@ def rename(src_path, dst_path, ftp=None):
     return success
 
 
+def move_contents(src_path,dst_path):
+    '''
+        Moves the files, sub-directories of the src_path to the dst_path
+
+        ----------
+
+        Arguments
+        -------------------------
+        `src_path` {string}
+            The path to the directory that will have its contents moved.
+        `dst_path` {string}
+            The path to the directory that will have the contents moved to.
+
+        Keyword Arguments
+        -------------------------
+        `arg_name` {type}
+                arg_description
+
+        Return {type}
+        ----------------------
+        return_description
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 02-05-2022 11:37:22
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: move_contents
+    '''
+    files = get_files(src_path)
+    move_array = []
+    for file in files:
+        file['dst_path'] = gen_dst_path(src_path,dst_path,file['file_path'])
+        move_array.append(file)
+    move(move_array)
+
+def move(src,dest=False,**kwargs):
+    ftp = obj.get_kwarg(["ftp"], None, None, **kwargs)
+    # ftp_credentials = obj.get_kwarg(["ftp_credentials"], None, None, **kwargs)
+    threading = obj.get_kwarg(["threading"], True, (bool), **kwargs)
+    max_threads = obj.get_kwarg(["max_threads"], 15, (int), **kwargs)
+    min_thread_threshold = obj.get_kwarg(["min thread threshold", "min files thread"], 100, (int), **kwargs)
+
+    move_list = []
+    if dest is False:
+        if isinstance(src, (list, tuple, dict)):
+            if isinstance(src, (list, tuple)):
+                for item in src:
+                    move_obj = _parse_copy_data_from_obj(item)
+                    if move_obj['src_path'] is not None and move_obj['dst_path'] is not None:
+                        move_list.append(_parse_copy_data_from_obj(item))
+            if isinstance(src, (dict)):
+                move_obj = _parse_copy_data_from_obj(src)
+                if move_obj['src_path'] is not None and move_obj['dst_path'] is not None:
+                    move_list.append(_parse_copy_data_from_obj(src))
+    else:
+        move_obj = _parse_copy_data_from_obj([src, dest])
+        move_list.append(move_obj)
+
+    if threading is True:
+        if len(move_list) >= min_thread_threshold:
+            _thread_file_action(move_list, action="move", max_threads=max_threads, min_thread_threshold=min_thread_threshold)
+            return
+
+    _move_files_from_array(move_list, ftp)
+    
+    
 def copy(src, dest=False, **kwargs):
     '''
         Copy a file from one location to another
@@ -489,7 +557,7 @@ def copy(src, dest=False, **kwargs):
             return
 
     _copy_files_from_array(copy_list, ftp)
-    # print(f"copy_list: {copy_list}")
+
 
 
 def _copy_files_from_array(file_list, ftp=None, attempted_delete=False):
@@ -511,6 +579,31 @@ def _copy_files_from_array(file_list, ftp=None, attempted_delete=False):
                 print(traceback.format_exc())
     return True
 
+def _move_files_from_array(file_list, ftp=None, attempted_delete=False):
+    for file in file_list:
+        try:
+            if ftp is not None:
+                directory.create(os.path.dirname(file['dst_path']), False, ftp=ftp)
+                ftp.upload_if_newer(file['src_path'], file['dst_path'])
+                continue
+
+            os.makedirs(os.path.dirname(file['dst_path']), exist_ok=True)
+            shutil.copy2(file['src_path'], file['dst_path'])
+            _delete_single_file(file['src_path'],False,ftp)
+            
+        except PermissionError as error:
+            if attempted_delete is False:
+                _delete_single_file(file['dst_path'])
+                _copy_files_from_array([file], ftp, True)
+            else:
+                print(f"Failed to copy file: {file['src_path']} to {file['dst_path']}.\n{error}")
+                print(traceback.format_exc())
+    return True
+
+
+
+
+
 
 def _delete_single_file(file_path, shred=False, ftp=None):
     '''
@@ -618,6 +711,15 @@ def _thread_file_action(file_list, **kwargs):
             end_idx = len(file_list)
         files_array = file_list[start_idx:end_idx]
         
+        
+        if action == "move":
+            if ftp_credentials is not None:
+                ftp = ftputil.FTPHost(ftp_credentials['address'], ftp_credentials['user_name'], ftp_credentials['password'])
+                ftp.synchronize_times()
+                threads.append(Thread(target=_move_files_from_array, args=(files_array,ftp)))
+                continue
+            threads.append(Thread(target=_move_files_from_array, args=(files_array,ftp)))            
+        
         if action == "copy":
             if ftp_credentials is not None:
                 ftp = ftputil.FTPHost(ftp_credentials['address'], ftp_credentials['user_name'], ftp_credentials['password'])
